@@ -1,7 +1,9 @@
+from . import io
 from .beams import *
 from .calibration import *
+from .cl import *
 from .instrument import *
 from .acquisition import *
 from .pointings import *
 
-__version__ = '3.0.1'
+__version__ = '3.1'
